summaryrefslogtreecommitdiffstats
path: root/src/fbgui/fbgui.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/fbgui/fbgui.h')
-rw-r--r--src/fbgui/fbgui.h18
1 files changed, 14 insertions, 4 deletions
diff --git a/src/fbgui/fbgui.h b/src/fbgui/fbgui.h
index 57f4a34..4f60b12 100644
--- a/src/fbgui/fbgui.h
+++ b/src/fbgui/fbgui.h
@@ -81,6 +81,13 @@ private:
void watchForTrigger();
bool checkHost() const;
void loadURL();
+
+ //test function to read and save CACertificates
+ QSslCertificate readCertificate(const QString&);
+
+ //Dump all Certificates in SSLConfiguration
+ void dumpCACertificates();
+
QByteArray generatePOSTData();
//----------------------------------
@@ -119,13 +126,16 @@ private slots:
void loadURLDone(bool success);
//SSL Error Handler for SSL Requests
- void sslErrorHandler(QNetworkReply* reply, const QList<QSslError> & errlist);
+ void sslErrorHandler(QNetworkReply*, const QList<QSslError> &);
//Error Handler for http Requests
- void httpErrorHandler(QNetworkReply* reply);
+ void httpErrorHandler(QNetworkReply*);
+
+ //Sets CaCertificates in QSslConfiguration
+ void registerCACertificates(const QList<QSslCertificate> & );
- //Sets CaCertificate in QSslConfiguration
- void registerCACertificate(QSslCertificate& cert);
+ //Sets LocalCertificate in QSslConfiguration
+ void setLocalCertificate(QSslCertificate& cert);
// shut off the system
void performShutDown();